Learn R Programming

Blaunet (version 3.0.0)

export.dyadic: Outputs Dyadic-Level Measures

Description

Returns dyadic-level Blau status measures previously computed with dyadic, allowing them to be analyzed in R or exported for use in other statistical software.

Usage

export.dyadic(blauObj)

Value

If dyadic-level results are available, returns the object stored in blauObj$dyadic, containing the dyadic Blau status measures. If no dyadic-level results are available, the function returns NULL after displaying a message.

Arguments

blauObj

A Blau object containing dyadic-level results, typically produced by calling dyadic on a Blau object.

Details

This function retrieves the dyadic-level results stored in blauObj$dyadic. If dyadic-level results have not yet been computed, the function displays the message “Nothing to export.”

Examples

Run this code
data(BSANet)
square.data <- BSANet$square.data
el <- BSANet$el
b <- blau(square.data, node.ids = "person", ecology.ids = "city", graph = el)
b <- dyadic(b, dev.range = rep(1.5, 3)) # 3 is the number of dimensions
export.dyadic(b)

Run the code above in your browser using DataLab